from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Int, File, String

H5Diff_V0_1_0 = CommandToolBuilder(tool="h5diff", base_command=["h5diff"], inputs=[ToolInput(tag="in_report", input_type=Boolean(optional=True), prefix="--report", doc=InputDocumentation(doc="Report mode. Print differences.")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Quiet mode. Do not produce output.")), ToolInput(tag="in_enable_error_stack", input_type=Boolean(optional=True), prefix="--enable-error-stack", doc=InputDocumentation(doc="Prints messages from the HDF5 error stack as they occur.")), ToolInput(tag="in_follow_symlinks", input_type=Boolean(optional=True), prefix="--follow-symlinks", doc=InputDocumentation(doc="Follow symbolic links (soft links and external links and compare the)\nlinks' target objects.\nIf symbolic link(s) with the same name exist in the files being\ncompared, then determine whether the target of each link is an existing\nobject (dataset, group, or named datatype) or the link is a dangling\nlink (a soft or external link pointing to a target object that does\nnot yet exist).\n- If both symbolic links are dangling links, they are treated as being\nthe same; by default, h5diff returns an exit code of 0.\nIf, however, --no-dangling-links is used with --follow-symlinks,\nthis situation is treated as an error and h5diff returns an\nexit code of 2.\n- If only one of the two links is a dangling link,they are treated as\nbeing different and h5diff returns an exit code of 1.\nIf, however, --no-dangling-links is used with --follow-symlinks,\nthis situation is treated as an error and h5diff returns an\nexit code of 2.\n- If both symbolic links point to existing objects, h5diff compares the\ntwo objects.\nIf any symbolic link specified in the call to h5diff does not exist,\nh5diff treats it as an error and returns an exit code of 2.")), ToolInput(tag="in_no_dangling_links", input_type=Boolean(optional=True), prefix="--no-dangling-links", doc=InputDocumentation(doc="Must be used with --follow-symlinks option; otherwise, h5diff shows\nerror message and returns an exit code of 2.\nCheck for any symbolic links (soft links or external links) that do not\nresolve to an existing object (dataset, group, or named datatype).\nIf any dangling link is found, this situation is treated as an error\nand h5diff returns an exit code of 2.")), ToolInput(tag="in_compare", input_type=Boolean(optional=True), prefix="--compare", doc=InputDocumentation(doc="List objects that are not comparable")), ToolInput(tag="in_nan", input_type=Boolean(optional=True), prefix="--nan", doc=InputDocumentation(doc="Avoid NaNs detection")), ToolInput(tag="in_count", input_type=Int(optional=True), prefix="--count", doc=InputDocumentation(doc="Print differences up to C. C must be a positive integer.")), ToolInput(tag="in_delta", input_type=Int(optional=True), prefix="--delta", doc=InputDocumentation(doc="Print difference if (|a-b| > D). D must be a positive number. Where a\nis the data point value in file1 and b is the data point value in file2.\nCan not use with '-p' or '--use-system-epsilon'.")), ToolInput(tag="in_relative", input_type=Int(optional=True), prefix="--relative", doc=InputDocumentation(doc="Print difference if (|(a-b)/b| > R). R must be a positive number. Where a\nis the data point value in file1 and b is the data point value in file2.\nCan not use with '-d' or '--use-system-epsilon'.")), ToolInput(tag="in_use_system_epsilon", input_type=Boolean(optional=True), prefix="--use-system-epsilon", doc=InputDocumentation(doc="Print difference if (|a-b| > EPSILON), EPSILON is system defined value. Where a\nis the data point value in file1 and b is the data point value in file2.\nIf the system epsilon is not defined,one of the following predefined\nvalues will be used:\nFLT_EPSILON = 1.19209E-07 for floating-point type\nDBL_EPSILON = 2.22045E-16 for double precision type\nCan not use with '-p' or '-d'.")), ToolInput(tag="in_exclude_path", input_type=File(optional=True), prefix="--exclude-path", doc=InputDocumentation(doc="'path'\nExclude the specified path to an object when comparing files or groups.\nIf a group is excluded, all member objects will also be excluded.\nThe specified path is excluded wherever it occurs.\nThis flexibility enables the same option to exclude either objects that\nexist only in one file or common objects that are known to differ.\nWhen comparing files, 'path' is the absolute path to the excluded;\nobject; when comparing groups, 'path' is similar to the relative\npath from the group to the excluded object. This 'path' can be\ntaken from the first section of the output of the --verbose option.\nFor example, if you are comparing the group /groupA in two files and\nyou want to exclude /groupA/groupB/groupC in both files, the exclude\noption would read as follows:\n--exclude-path '/groupB/groupC'\nIf there are multiple paths to an object, only the specified path(s)\nwill be excluded; the comparison will include any path not explicitly\nexcluded.\nThis option can be used repeatedly to exclude multiple paths.")), ToolInput(tag="in_mode_print_above", input_type=String(optional=True), prefix="-v", doc=InputDocumentation(doc="mode: print the above plus a list of objects and warnings")), ToolInput(tag="in_file_one", input_type=Int(), position=0, doc=InputDocumentation(doc="File name of the first HDF5 file")), ToolInput(tag="in_file_two", input_type=Int(), position=1, doc=InputDocumentation(doc="File name of the second HDF5 file")), ToolInput(tag="in_options", input_type=String(), position=0, doc=InputDocumentation(doc="-h, --help\nPrint a usage message and exit."))], outputs=[ToolOutput(tag="out_exclude_path", output_type=File(optional=True), selector=InputSelector(input_to_select="in_exclude_path", type_hint=File()), doc=OutputDocumentation(doc="'path'\nExclude the specified path to an object when comparing files or groups.\nIf a group is excluded, all member objects will also be excluded.\nThe specified path is excluded wherever it occurs.\nThis flexibility enables the same option to exclude either objects that\nexist only in one file or common objects that are known to differ.\nWhen comparing files, 'path' is the absolute path to the excluded;\nobject; when comparing groups, 'path' is similar to the relative\npath from the group to the excluded object. This 'path' can be\ntaken from the first section of the output of the --verbose option.\nFor example, if you are comparing the group /groupA in two files and\nyou want to exclude /groupA/groupB/groupC in both files, the exclude\noption would read as follows:\n--exclude-path '/groupB/groupC'\nIf there are multiple paths to an object, only the specified path(s)\nwill be excluded; the comparison will include any path not explicitly\nexcluded.\nThis option can be used repeatedly to exclude multiple paths."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    H5Diff_V0_1_0().translate("wdl", allow_empty_container=True)

